from epics import caput,caget

def encoder_dictionary_entry(name):
    """
    returns a dictionary with the encoder pvs
    encoder_dictionary_entry(name) = encoder_ioc, motor_ioc, encoder_list

    """
    d={
        'slit2B':("29idMini1:",[13,14,15,16]),
        'slit3D':("29idMini2:",[26,27]),
        'ARPES':("ARPES:",[1,2,3,4]),
    }
    return d[name]

def encoder_sync(name):
    """
    sync all the encoders for name
    """
    encoder_ioc, motor_ioc, encoder_list = encoder_dictionary_entry(name)
    for encoder_num in encoder_list:
        pv = motor_ioc+":m"+str(encoder_num)+".SYNC"
        caput(pv,1)

def encoders_reset(name,Hcenter,Vcenter):
    """
    Resetting Slit 2B encoders to 0 for a given position (Hcenter,Vcenter).
    Slit size need to be set to 0.

    Previously: Reset_Slit2B_Encoders
    """
    encoder_sync('name')  
    encoder_ioc, motor_ioc, encoder_list = encoder_dictionary_entry(name)

    print('\nCurrent Position:')
    for e_num in encoder_list:
        pv = encoder_ioc+'e'+(e_num)+'Pos'
        print('e'+(e_num)+' = '+str(caget(pv)))
    
    print('\nSetting all Offsets to 0:')
    for e_num in encoder_list:
        pv = encoder_ioc+'e'+(e_num)+'Pos.EOFF'
        caput(pv,0)
    
    print('\nCurrent Position:')
    for e_num in encoder_list:
        pv = encoder_ioc+'e'+(e_num)+'Pos'
        print('e'+(e_num)+' = '+str(caget(pv)))

    print('\nSetting back Offsets:')
    for e_num in encoder_list:
        pos_pv = encoder_ioc+'e'+(e_num)+'Pos' 
        offset_pv = encoder_ioc+'e'+(e_num)+'Pos.EOFF' 
        caput(offset_pv,-caget(pos_pv))

    print('\nCurrent Position:')
    for e_num in encoder_list:
        pv = encoder_ioc+'e'+(e_num)+'Pos'
        print('e'+(e_num)+' = '+str(caget(pv)))

    encoder_sync(name)
    print('sync '+name)
